==> everycomp-1.20-2.8.5-fabric-sources.jar: net/mehvahdjukaar/every_compat/mixins/LootTablesHackMixin.java <==
package net.mehvahdjukaar.every_compat.mixins;

import net.mehvahdjukaar.every_compat.ECPlatStuff;
import net.mehvahdjukaar.every_compat.EveryCompat;
import net.mehvahdjukaar.every_compat.api.SimpleEntrySet;
import net.mehvahdjukaar.moonlight.api.util.Utils;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_2680;
import net.minecraft.class_2960;
import net.minecraft.class_3218;
import net.minecraft.class_4970;
import net.minecraft.class_52;
import net.minecraft.class_8567;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;
import org.spongepowered.asm.mixin.injection.callback.LocalCapture;

import java.util.List;

@Mixin(class_4970.class)
public abstract class LootTablesHackMixin {

    @Shadow
    public abstract class_1792 asItem();

    @Inject(method = "getDrops", cancellable = true,
            at = @At(value = "INVOKE", target = "Lnet/minecraft/world/level/storage/loot/LootTable;getRandomItems(Lnet/minecraft/world/level/storage/loot/LootParams;)Lit/unimi/dsi/fastutil/objects/ObjectArrayList;"
            ), locals = LocalCapture.CAPTURE_FAILEXCEPTION)
    public void addSimpleFastECdrops(class_2680 state, class_8567.class_8568 builder, CallbackInfoReturnable<List<class_1799>> cir, class_2960 resId,
                                     class_8567 lootParams, class_3218 serverLevel, class_52 lootTable) {
        if (lootTable == class_52.field_948 && EveryCompat.isMyIdOrAddon(Utils.getID(state.method_26204()).method_12836())) {
            if (SimpleEntrySet.isSimpleDrop(state.method_26204())) {
                cir.setReturnValue(ECPlatStuff.modifyLoot(resId, List.of(this.asItem().method_7854()),
                        lootParams));
            }
        }
    }
}

==> everycomp-1.21-2.11.18-fabric-sources.jar: net/mehvahdjukaar/every_compat/mixins/LootTablesHackMixin.java <==
package net.mehvahdjukaar.every_compat.mixins;

import com.llamalad7.mixinextras.sugar.Local;
import net.mehvahdjukaar.every_compat.ECPlatStuff;
import net.mehvahdjukaar.every_compat.EveryCompat;
import net.mehvahdjukaar.every_compat.api.SimpleEntrySet;
import net.mehvahdjukaar.moonlight.api.util.Utils;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_2680;
import net.minecraft.class_4970;
import net.minecraft.class_52;
import net.minecraft.class_5321;
import net.minecraft.class_8567;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import java.util.List;

@Mixin(class_4970.class)
public abstract class LootTablesHackMixin {

    @Shadow
    public abstract class_1792 asItem();

    @Inject(method = "getDrops", cancellable = true,
            at = @At(value = "INVOKE", target = "Lnet/minecraft/world/level/storage/loot/LootTable;getRandomItems(Lnet/minecraft/world/level/storage/loot/LootParams;)Lit/unimi/dsi/fastutil/objects/ObjectArrayList;"
            ))
    public void everyComp$addFastDrops(class_2680 state, class_8567.class_8568 params, CallbackInfoReturnable<List<class_1799>> cir,
                                       @Local class_52 lootTable, @Local class_8567 lootParams,
                                       @Local class_5321<class_52> resId) {
        if (lootTable == class_52.field_948 && EveryCompat.isMyIdOrAddon(Utils.getID(state.method_26204()).method_12836())) {
            if (SimpleEntrySet.isSimpleDrop(state.method_26204())) {
                cir.setReturnValue(ECPlatStuff.modifyLoot(resId.method_29177(), List.of(this.asItem().method_7854()),
                        lootParams));
            }
        }
    }
}
